@@ -4,7 +4,7 @@
 #' @inheritParams base::list.files
 #' @returns An 'archive' object representing the new archive (invisibly).
 #' @export
-archive_write_dir <- function(archive, dir, format = NULL, filter = NULL, options = character(), ..., recursive = TRUE, full.names = FALSE) {
+archive_write_dir <- function(archive, dir, format = NULL, filter = NULL, options = character(), password = NA_character_, ..., recursive = TRUE, full.names = FALSE) {
   assert("`dir` {dir} is not readable",
     is_readable(dir))
 
@@ -16,7 +16,7 @@ archive_write_dir <- function(archive, dir, format = NULL, filter = NULL, option
   on.exit(setwd(old))
   files <- dir(".", ..., recursive = recursive, full.names = full.names)
 
-  archive_write_files(archive, files, format = format, filter = filter, options = options)
+  archive_write_files(archive, files, format = format, filter = filter, options = options, password = password)
 
   invisible(archive(archive, options = character()))
 }
